import torch
import numpy as np

def freeze_layers(model, freeze_from):

    for p in model.parameters():
        p.requires_grad = False
    for p in freeze_from.parameters():
        p.requires_grad = True

    return model

class MixUp:
    @staticmethod
    def mixup_data(x, y, alpha=1.0, device='cpu'):
        if alpha > 0:
            lam = np.random.beta(alpha, alpha)
        else:
            lam = 1

        batch_size = x.size()[0]
        
        index = torch.randperm(batch_size).to(device)
    
        mixed_x = lam * x + (1 - lam) * x[index, :]
        y_a, y_b = y, y[index]
        
        return mixed_x, y_a, y_b, lam

    @staticmethod
    def mixup_criterion(criterion, pred, y_a, y_b, lam):
        return lam * criterion(pred, y_a) + (1 - lam) * criterion(pred, y_b)
    